'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var getChildren = function getChildren(nodePath) {
  var children = nodePath.node ? [].concat(_toConsumableArray(nodePath.node.children)) : [].concat(_toConsumableArray(nodePath.children));
  return children;
};

var createElement = function createElement(types, children, attribute) {
  var opening = types.jSXOpeningElement(types.jSXIdentifier('div'), attribute || [], false);
  var closing = types.jSXClosingElement(types.jSXIdentifier('div'));

  return types.jSXElement(opening, closing, children, false);
};

var getAttributes = function getAttributes(nodePath) {
  var attributes = nodePath.node ? [].concat(_toConsumableArray(nodePath.node.openingElement.attributes)) : [].concat(_toConsumableArray(nodePath.openingElement.attributes));

  return attributes;
};

var getAttribute = function getAttribute(nodePath, name) {
  var attributes = getAttributes(nodePath);
  attributes = attributes.find(function (attribute) {
    return attribute.name.name === name;
  });

  return attributes;
};

var getAttributeIndex = function getAttributeIndex(nodePath, name) {
  var attribute = getAttribute(nodePath, name);
  var index = getAttributes(nodePath).indexOf(attribute);

  return index;
};

var getChildIndex = function getChildIndex(nodePath, child) {
  var children = getChildren(nodePath);

  return children.indexOf(child);
};

var removeChild = function removeChild(nodePath, child) {
  var index = getChildIndex(nodePath, child);
  if (nodePath.node) {
    nodePath.node.children.splice(index, 1);
  } else {
    nodePath.children.splice(index, 1);
  }
};

var removeAttribute = function removeAttribute(nodePath, index) {
  var openingElement = nodePath.node ? nodePath.node.openingElement.attributes : nodePath.openingElement.attributes;

  openingElement.splice(index, 1);
};

/*
 Remove and collects B nodes between index 0 node and A.

 * Parameter *
 param [String] nodeName - A
 param [String] targetName - B

 return [Array]
 */
var getBetweenNodes = function getBetweenNodes(types, nodePath, nodeName, targetName) {
  var result = [];

  var children = getChildren(nodePath).filter(function (node) {
    return types.isJSXElement(node);
  });
  children.some(function (child) {
    var attribute = getAttribute(child, targetName);

    if (attribute) {
      result.push(child);

      removeChild(nodePath, child);
      return false;
    } else {
      attribute = getAttribute(child, nodeName);
    }

    return attribute;
  });

  return result;
};

exports.default = { getChildren: getChildren, createElement: createElement, getAttributes: getAttributes, getAttribute: getAttribute, getAttributeIndex: getAttributeIndex, getChildIndex: getChildIndex, removeChild: removeChild, removeAttribute: removeAttribute, getBetweenNodes: getBetweenNodes };